 /**
 * PROJECT: Professional Java Electron Crystallography Tools
 * @author: Xingzhong Li
 * @version: February 18, 2012
 *
 * read and write the size value to a file
 * allow user to change value
 *
 * 05-11-2024
 */

package xzli.jecp.structure;

import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

import java.awt.*;
import java.awt.event.*;

import java.text.DecimalFormat;
import java.net.*;         //imageIcon
import java.util.*;
import java.io.*;
 
public class jecp_displaySizeDialog extends JDialog {
	
	int original_length, length;
	JLabel percentJLB;
	JSlider percentJSD; 
	JButton saveJBT, doneJBT;	
	
	jecp_struGUI gui;
	jecp_struPanel structure_panel;
	
	public jecp_displaySizeDialog(jecp_struGUI owner, jecp_struPanel panel) {
    	super(owner);
    	
    	gui = owner;
    	setTitle("Window size");
    	
    	structure_panel = panel;
		
		setModal(false);
		setSize(250,160);

		Toolkit tk = Toolkit.getDefaultToolkit ();
    	Dimension screen = tk.getScreenSize ();
		original_length = (int) Math.min(screen.getWidth(), screen.getHeight());  
		setLocationRelativeTo(null);
		
		length = (int) (original_length*read_data());
		percentJLB = new JLabel(""+length, JLabel.CENTER);
		percentJSD= new JSlider(50, 100, (int)(read_data()*100.0));  //JSlider(int min, int max, int value)
		gui.setSize(length, length);

		getContentPane().add(createPanel());
		
		setVisible(false);

    	setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
		// setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);

    	WindowListener wndCloser = new WindowAdapter() {
      		public void windowClosing(WindowEvent e) {
			setVisible(false);
//			imagePanel.saed.paramPrev.size = imagePanel.saed.paramCurr.size; 
//			imagePanel.saed.paramPrev.ppi = imagePanel.saed.paramCurr.ppi; 
 		}
    	};
    	addWindowListener(wndCloser);
        }

	static private URL getResource(String resource){
		return jecp_displaySizeDialog.class.getResource(resource);
	}

	public JPanel createPanel(){
								
		JPanel center_panel = new JPanel();
		center_panel.setBorder(new TitledBorder(new EtchedBorder(),"Size adjustment"));
			
    	percentJSD.setPreferredSize(new Dimension(200, 30));
    	percentJSD.addChangeListener(new ChangeListener() {
      		public void stateChanged(ChangeEvent event) {
					length = original_length*percentJSD.getValue()/100;
  					percentJLB.setText(""+length);
  					gui.setSize(length, length+100);
  					structure_panel .structure3D.WIDTH = length;
    				structure_panel.structure3D.HEIGHT = length;
    				structure_panel.repaint();
      		}
    	});
  	
  		center_panel.add(percentJLB);
  		center_panel.add(percentJSD);
//------------------------------------------------------------------------------			
		
		JPanel south_panel = new JPanel();
		
		saveJBT = new JButton("Save");	
    	saveJBT.addActionListener(new ActionListener(){
  			public void actionPerformed(ActionEvent e){
				write_data( (double)length/original_length);
   				}
			});		
		
		doneJBT = new JButton("Done");	
    	doneJBT.addActionListener(new ActionListener(){
  			public void actionPerformed(ActionEvent e){
			setVisible(false);
   				}
			});
    	south_panel.add(saveJBT);		
		south_panel.add(doneJBT);
		
    	JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		
        panel.add(center_panel, BorderLayout.CENTER);            
		panel.add(south_panel, BorderLayout.SOUTH);
		    	
		return panel;
		}

/*		
	private void warningDialog(){
 				JOptionPane.showMessageDialog(null, "Input format is incorrect  ! ", 
 				"WARNING", JOptionPane.WARNING_MESSAGE);		
		}

	private void rangeDialog(String range){
 				JOptionPane.showMessageDialog(null, range, 
 				"INFO", JOptionPane.INFORMATION_MESSAGE);		
		}
*/
//---------------------------------------------------------------------------------------------------------------------------------------------------
 /*
  * for the length = window * percentage of svat only
  */
	public double read_data(){	
	double percent =0.9;
	File f = new File("svat.pct");
	if(f.exists() && !f.isDirectory()) {	
    try{
      	ObjectInput input = new ObjectInputStream (new FileInputStream("svat.pct"));
		Double obj = (Double) input.readObject();		
		percent = obj.doubleValue();
		input.close();
		}
		catch(ClassNotFoundException ex){			
			ex.printStackTrace();						
    		}
			catch(Exception ex){
		   		ex.printStackTrace();
	   			} 						
	}		
	return percent;
	}
	
	public void write_data( double percent){
    	try{
		  	OutputStream file = new FileOutputStream("svat.pct");
      		OutputStream buffer = new BufferedOutputStream(file);
      		ObjectOutput output = new ObjectOutputStream(buffer);
    			   			
    		Double obj = Double.valueOf(percent);
    		
			output.writeObject(obj);
        	output.close();
			}    			    			
    		catch(IOException ex){
    			ex.printStackTrace();    		 
		}
	}
			
//---------------------------------------------------------------------------------------------------------------------------------------------------
  	public static void main(String arg[]){
		jecp_struGUI gui = new jecp_struGUI();
  		jecp_displaySizeDialog dialog = new jecp_displaySizeDialog(gui, null);
  		dialog.setVisible(true);
  		}

       } //end of class

